#
# spec file for package ghc-persistent-sqlite
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name persistent-sqlite
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        2.9.2
Release:        lp151.1.4
Summary:        Backend for the persistent library using sqlite3
License:        MIT
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-conduit-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-microlens-th-devel
BuildRequires:  ghc-monad-logger-devel
BuildRequires:  ghc-old-locale-devel
BuildRequires:  ghc-persistent-devel
BuildRequires:  ghc-resource-pool-devel
BuildRequires:  ghc-resourcet-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-unliftio-core-devel
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  glibc-devel
BuildRequires:  sqlite3-devel
%if %{with tests}
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-persistent-template-devel
BuildRequires:  ghc-temporary-devel
%endif

%description
This package includes a thin sqlite3 wrapper based on the direct-sqlite
package, as well as the entire C library, so there are no system dependencies.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires:       glibc-devel
Requires:       sqlite3-devel
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%prep
%setup -q -n %{pkg_name}-%{version}
cabal-tweak-flag systemlib True

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc ChangeLog.md

%changelog
* Mon Dec 31 2018 psimons@suse.com
- Update persistent-sqlite to version 2.9.2.
  [#]# 2.9.2
  * Add enableExtendedResultCodes and disableExtendedResultCodes functions
* Wed Dec 19 2018 psimons@suse.com
- Update persistent-sqlite to version 2.9.1.
  [#]# 2.9.1
  * Bump vendored SQLite library to [3.26.0](https://www.sqlite.org/releaselog/3_26_0.html) to address [RCE bug: `magellan`](https://blade.tencent.com/magellan/index_en.html).
* Mon Oct 15 2018 psimons@suse.com
- Update persistent-sqlite to version 2.9.0.
  [#]# 2.9.0
  * Added support for SQL isolation levels to via SqlBackend. [#812] SQLite technically only supports Serializable.
  * Update the vendored SQLite C library from 3.22.0 to 3.25.2. See [the SQLite changelog](https://sqlite.org/changes.html) for details.
  * Fix [832](https://github.com/yesodweb/persistent/issues/832): `repsertMany` now matches `mapM_ (uncurry repsert)` and is atomic.
* Thu Aug 30 2018 psimons@suse.com
- Update persistent-sqlite to version 2.8.2.
  [#] Changelog for persistent-sqlite
  [#]# 2.8.2
  * Add the `extraPragmas` setting
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update persistent-sqlite to version 2.8.1.2.
  * Add flag to enable full-text search extensions (enabled by default)
  * Add flag to enable URI filename support (enabled by default)
  * Add flag to enable using usleep (enabled by default)
  - Enabling usleep allows sqlite to use a finer granularity when sleeping (reduces time between locks)
  * Add flag to enable json1 extension (enabled by default)
  * Update the vendored SQLite C library from 3.19.3 to 3.22.0. See [the SQLite changelog](https://sqlite.org/changes.html) for details.
  * Updated `SqlBackend` definition to set `connPutManySql`. [#770](https://github.com/yesodweb/persistent/pull/770)
  * Switch from `MonadBaseControl` to `MonadUnliftIO`
  * Adds a new function `stepConn`, which uses an additional parameter to give more detailed error messages [#750](https://github.com/yesodweb/persistent/pull/750)
  * Restores the previous function signature of `step`, which was accidentally changed in 2.6.3.2
  * This release accidentally broke API, and is deprecated on Hackage.
  * Provide more detailed error messages when using the `step` function [#730](https://github.com/yesodweb/persistent/pull/730)
  * Fix migration to avoid creating foreign-key constraints in temporary tables [#736](https://github.com/yesodweb/persistent/pull/736)
  * Add 'use-pkgconfig' flag to use pkg-config to find system SQLite library.
  * Update the vendored SQLite C library from 3.12.1 to 3.19.3. See [the SQLite changelog](https://sqlite.org/changes.html) for details.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Tue Mar 14 2017 psimons@suse.com
- Update to version 2.6.2 with cabal2obs.
* Mon Feb 27 2017 psimons@suse.com
- Update to version 2.6.0.1 with cabal2obs.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 2.6 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 2.2.1 revision 0 with cabal2obs.
* Thu Mar 10 2016 mimi.vx@gmail.com
- update to 2.2.1
  * upgrade to SQLite 3.8.11.1
* Thu Nov 19 2015 mimi.vx@gmail.com
- initial commit
